*****************************
*QIPSR Introduction to Stata*
*****************************

*For more information about QIPSR, please visit http://qipsr.as.uky.edu/* 

**********************************
*The help command is your friend *
**********************************
	help
	help regress
	help collapse 
	
*StataCorp also provides many tutorial videos.  For further instruction, please visit: https://www.youtube.com/user/statacorp* 

*The online Stata community is also extremely informative.  A very helpful forum can be found at: https://www.statalist.org/.  	


********************************
*Helpful Commands to Start With*
********************************

version 15
clear all 
set more off 
cd "C:\Users\oconn\Desktop\Intro to Stata Workshop"
log using workshop_log, replace 

		
**************************
*Loading Data into Stata *
**************************

	**************************************
	*Importing data from the Internet *
	**************************************
	    *Stata file*
		use http://www.stata-press.com/data/r9/apple.dta
		*Delimited file*
		import delimited http://www.uky.edu/~clthyn2/coup_data/powell_thyne_ccode_year.txt, clear 
		clear all
	
	*********************
	*Importing csv file *
	*********************
		import delimited workshop.csv, clear 		
		clear all
	*************************
	*Importing an excel file*	
	*************************
		import excel workshop.xlsx, sheet("workshop") firstrow clear
		clear all
	**************************
	*Importing Stata dataset *
	**************************
		use workshop_a.dta, clear
		
***********************
*Merging Two Datasets *
***********************
		
	frame create frame2
	frame change frame2
	use workshop_b.dta 
	
	frame change default
	
	merge 1:1 id using workshop_b.dta	
		
		**************************************************************************
		*This command performs a one-to-one merge; it merges the dataset already *
		*opened in Stata with another dataset.								     *
		**************************************************************************

******************
*Data Management *
******************
 
	*******************
	*Basic Operations *
	*******************

		browse
			*************************
			*Browse the variable(s) *
			*************************
			
		edit
			***********************
			*Edit the variable(s) *
			***********************
		
		sort ses
			***********************
			*Sort the variable(s) *
			***********************
		
		order gender read write

			
	***************************************
	*Examining Dataset for Missing Values *
	***************************************
		
		misstable sum, all					
			**************************************
			*creates a missing observation table *
			**************************************
			
********************************************************
*Summary Statistics and Examining a Variable in Detail *
********************************************************

	describe
		************************************
		*Describe the variables in dataset *
		************************************
		
	tab gender 
	
	tab gender race
		****************************************************
		*Performs a crosstab for variables gender and race *
		****************************************************
		
	list gender-read in 1/10 
		*******************************************************************
		*List the first 10 observations for variables from gender to read *
		*******************************************************************
		
	summarize
		********************************************
		*Summary statistics table of all variables *
		********************************************
		
	summarize read math science write, detail
		******************************************************************
		*Summary statistics for variables read, math, science, and write *
		******************************************************************
		
	summarize if read>=60 
		*************************************************************
		*Summary statistics for all variables if variable read > 60 *
		*************************************************************
		
	summarize if prgtype=="academic" 
		************************************************************************
		*Summary statistics for all variables if variable prgtype = "academic" *
		************************************************************************
		
	summarize read, detail 
		**************************************
		*Summary the variable read in detail *
		**************************************
		
	centile read
		******************************************
		*Looking at variable values by percentile*
		******************************************
		
	codebook read
		**************************************
		*Shows more details about a variable *
		**************************************
		
******************************			
*Looking at data graphically *
******************************

	histogram read
	hist read, freq normal 
		********************************************************************
		*Histogram of variable read, and add a normal density to the graph *
		********************************************************************
		
	ladder read										
		*******************************************************************
		*list of ladder of powers transformations. Pick the lowest value. *
		*******************************************************************
		
	gladder read
		******************************
		*Ladder of powers histograms *
		******************************
		
	qladder read
		*****************************************
		*Ladder of powers quantile-normal plots *
		*****************************************
		
		
***************************************************************
*Graphing to show relationships between two or more variables *
***************************************************************

	graph matrix read math science write, half
		***********************************************************
		*Scatterplots of variables read, math, science, and write *
		***********************************************************
		
	twoway (scatter math read) 
		******************************************
		*Scatterplot of variables write and read *
		******************************************
		
	twoway (lpolyci write read)
		**********************************************************
		*Local polynomial smooth plots with confidence intervals *
		**********************************************************
		
	twoway (scatter write read) (lpolyci write read)
		******************************
		*Combine two previous graphs *
		******************************
		
	twoway (scatter write read) ///
		(lpoly write read if race==1) ///
		(lpoly write read if race==2) ///
		(lpoly write read if race==3)
		*****************************************************
		*Previous graph by race; graph looks a little messy *
		*****************************************************
		
	twoway (scatter write read) ///
		(lpoly write read), by(race)
		*******************************************
		*Better graph to show differences by race *
		*******************************************
		
	twoway (scatter write read, mcolor(forest_green)) ///
		(lfit write read, lcolor(blue) lpattern(solid) cmissing(y)), ///
		by(, title(Reading Scores by Writing Scores) ///
		subtitle(Broken down by Socioeconomic Status) ///
		note(The blue line is a fitted value)) by(ses) 
		*******************************************
		*More complicated version *
		*******************************************
		
*****************
*Modifying data *
*****************
	
			
		label variable schtyp "type of school" 				
			*********************************************
			*Label the variable schtyp "type of school" *
			*********************************************
			
		label define schtypl 1 "public school" 2 "private school"
		label values schtyp schtypl
		
		rename gender female 
			************************************************* 
			*Change the variable name from gender to female *
			*************************************************
			
		generate lnread=ln(read)
		generate newvar=read+math
			*****************************************************
			*Generates a new variable, which is the log of read *
			*****************************************************
			
		drop socst  										
			*********************************************************
			*Drops and deletes the variable schtyp from the dataset *
			*********************************************************
			
		tabulate race, generate (r)									
		   ************************************************************************
		   *From the categorical variable race, generates a set of dummy variables*
		   ************************************************************************
		
		replace string = subinstr(string, "$", "",.) 		
			***********************************************************************
			*cleans the variable by removing symbols that Stata doesn't understand*
			***********************************************************************
			
		destring string, generate(string2)					
			**********************************************************************
			*converts the variable from a block of text into a numerical variable*
			**********************************************************************
		
********************************************************************
*Basic Statistical Tests (Bivariate, OLS, logit) and visualization*
********************************************************************

pwcorr math female race ses read write science schtyp, star(.05)
			****************************************************************
			*Coorelation matrix [this command will not run if you have not
			*renamed race_d4 to white
			****************************************************************

ttest math, by(female)
			************************************************
			*T-test of significance for math, by gender *
			************************************************


tab2 female ses, chi
tab2 female ses, chi exact expected
			*******************
			*Chi-square test*
			*******************
			
anova math schtyp
			***************
			*ANOVA test*
			***************

regress math ses read science
		***************
		*OLS model *
		***************

recode math 0/52.645=0 else=1, gen(math_r)
		********************************************************************
		*Creating a dichotomous variable, above the mean, for logit model*
		********************************************************************

logit math_r ses read science
		************************************************************
		*Logit model, with option for Odds Ratios to be displayed *
		************************************************************
	
****************************
*Outputting Models to Table*
****************************
regress math ses read science
est sto m1 
*This tell Stata to store the most recent model as model 1*
logit math_r ses read science, or
est sto m2
esttab m1 m2 using workshop_table.rtf, replace title("Workshop Table") mtitle("Model 1""Model 2")

log close 
